Module memory

Module memory 

In-memory data store backed by flat arrays with RwLock protection.

Structs

InMemoryStore
In-memory data store using flat tables with RwLock protection.
StoreConfig
Configuration for the in-memory data store.

Enums

StoreError
Errors produced by in-memory store configuration and setup helpers.

Constants

MAX_TABLE_SIZE
Maximum number of entries in any Modbus data table.