pub enum StoreError {
TableTooLarge {
table: &'static str,
count: usize,
max: usize,
},
AddressOutOfRange {
table: &'static str,
address: u16,
len: usize,
},
FileNumberOutOfRange {
file_number: u16,
minimum: u16,
},
FileRecordOutOfRange {
record_number: u16,
maximum: u16,
},
}Expand description
Errors produced by in-memory store configuration and setup helpers.
Variants
TableTooLarge
A configured table has more entries than Modbus can address.
Fields
AddressOutOfRange
A setup helper addressed outside the configured table.
Fields
FileNumberOutOfRange
A setup helper used file number 0, which is outside the Modbus range.
FileRecordOutOfRange
A setup helper used a file record outside the 10,000-record file range.