Data store abstraction for the four Modbus data tables, plus optional file-record, FIFO-queue, and serial-line-diagnostic capabilities.
Modules
- memory
- In-memory data store backed by flat arrays with
RwLockprotection.
Structs
- Comm
Event Log - Snapshot of the communications event log returned by Get Comm Event Log (FC 0x0C, Spec V1.1b3 6.10).
- Comm
Event LogMeta - Fixed fields returned with a Get Comm Event Log response (FC 0x0C).
Traits
- Data
Store - Async trait abstracting the four Modbus data tables (Spec V1.1b3 4.3).