In-memory data store backed by flat arrays with RwLock protection.
Structs
- InMemory
Store - In-memory data store using flat tables with
RwLockprotection. - Store
Config - Configuration for the in-memory data store.
Enums
- Store
Error - Errors produced by in-memory store configuration and setup helpers.
Constants
- MAX_
TABLE_ SIZE - Maximum number of entries in any Modbus data table.